@@ -2199,7 +2199,8 @@ def main():
                 raise Exception("There are some devices which are " + args["device_status"].lower())
             
     except Exception as e:
-        raise Exception("Oops!", e)
+        print(traceback.format_exc())
+        sys.exit(-1)
 
 def killProcess():
     try:
@@ -2211,10 +2212,10 @@ def killProcess():
 if __name__ == "__main__":
     try:
         main()
-        killProcess()
         print("Execution completed successfully!")
         sys.exit(0)
     except Exception as e:
-        killProcess()
-        print("Returning error code -1!, Error: " + str(e) )
+        print(traceback.format_exc())
         sys.exit(-1)
+    finally:
+        killProcess()
